PROGRAM test_input

USE input
IMPLICIT NONE
LOGICAL :: eof
CHARACTER(LEN=16) :: w
DOUBLE PRECISION :: T1, T2, DT, R1, R2, DR, lfact=1d0, Tzero=0d0, &
    value(10)
INTEGER :: i, int(10)

call input_options(echo_lines=.true.,error_flag=1)
do
  call read_line(eof)
  if (eof) exit
  call readu(w)
  select case(w)
  case("STOP","FINISH","END")
    exit
  case("")
    print "(1x)"    !  Echo blank lines
  case("UNITS")
    do while (item .lt. nitems)
      call readu(w)
      select case(w)
      case("CELSIUS")
        Tzero=273.15d0
        print "(A)", "Temperatures now in Celsius"
      case("K","KELVIN")
        Tzero=0d0
        print "(A)", "Temperatures now in Kelvin"
      case("ANGSTROM")
        lfact=0.52917725
        print "(A)", "Distances now in Angstrom"
      case("NM")
        lfact=0.052917725
        print "(A)", "Distances now in nm"
      case("BOHR")
        lfact=1d0
        print "(A)", "Distances now in Bohr"
      case default
        call report ("Unrecognized unit name "//trim(w),.true.)
      end select
    end do
  case("TEMPERATURES","TEMPERATURE","TEMPS")
    do while (item .lt. nitems)
      call readu(w)
      select case(w)
      case("FROM")
        call readf(T1)
        T1=T1+Tzero    !  Convert to Kelvin
      case("TO")
        call readf(T2)
        T2=T2+Tzero
      case("STEP","BY")
        call readf(dT)
      case default
        call reread(-1)
        call readf(T1)
        T1=T1+Tzero
      end select
    end do
    print "(A,F8.3,A,F8.3,A,F8.3,A)",                           &
        "Temperatures from ", T1, " to ", T2, " in steps of ", dT, " K"
  case("RANGE")
    do while (item .lt. nitems)
      call readu(w)
      select case(w)
      case("FROM")
        call readf(R1,lfact)
      case("TO")
        call readf(R2,lfact)
      case("STEP","BY")
        call readf(dR,lfact)
      case default
        call reread(-1)
        call readf(R1,lfact)
        R1=R1/lfact
      end select
    end do
    print "(A,F8.3,A,F8.3,A,F8.3,A)",                           &
        "Distances from ", R1, " to ", R2, " in steps of ", dR, " bohr"
  case ("ERRORS")
    call readu(w)
    select case(w)
    case("HARD")
      call input_options(error_flag=0)
    case("ZERO")
      call input_options(error_flag=1)
    case("SOFT")
      call input_options(error_flag=2)
    end select
  case ("MISCELLANEOUS","MISC","REAL")
    i=0
    do while (item < nitems)
      i=i+1
      call readf(value(i))
    end do
    print "(A,10F12.6)", "Values are ", value(1:i)
  case ("INTEGER")
    i=0
    do while (item < nitems)
      i=i+1
      call readi(int(i))
    end do
    print "(A,10I6)", "Values are ", int(1:i)
  case default
    call report ("Principal keyword "//trim(w)//" not recognized",.true.)
  end select
end do

END program test_input
